@@ -139,7 +139,7 @@ class StandardFunction:
         :param data_vector_2:
         :return:
         """
-        return np.divide(data_vector_1, data_vector_2, units)
+        return np.divide(data_vector_1, data_vector_2)
 
     @staticmethod
     def row_sum(matrix: np.ndarray):
@@ -297,54 +297,6 @@ class StandardFunction:
 
         return np.array(return_value_nic).reshape(-1, 1)
 
-    # @staticmethod
-    # def HIC_15(time: np.ndarray, a_res: np.ndarray, units, flag=True):
-    #     """
-    #     time vector in ms
-    #     a_res in mm/s²
-    #
-    #     make that consistent and use definitions here!
-    #     use more outputs here!
-    #     possible to return HIC for each time step
-    #     :param time:
-    #     :param a_res:
-    #     :param units:
-    #     :param flag(HIC15/HIC36):
-    #
-    #     :return:
-    #     """
-    #     t = time.flatten() / units.second()  # t in [s]
-    #     a_res = a_res.flatten()
-    #     a_res /= units.meter() / (units.second() ** 2)  # a_res in [m/s^2]
-    #     a_res /= units.grav_const  # a_res in [g]
-    #
-    #     vel = cumtrapz(a_res, t, initial=0)
-    #     hic15 = []
-    #     time2 = []
-    #     dt = (t[1] - t[0])
-    #     if flag:
-    #         nidx = int(round(0.015 / dt))
-    #     else:
-    #         nidx = int(round(0.036 / dt))
-    #
-    #     # TODO
-    #     # RuntimeWarning: invalid value encountered in double_
-    #     # scalars temp.append((tdiff) * (((vel[jt] - vel[ut]) / (tdiff)) ** 2.5))
-    #     # problem None values
-    #
-    #     for ut in range(len(t) - 1):
-    #         temp = []
-    #         for jt in range(ut + 1, min([len(t), ut + nidx])):
-    #             tdiff = t[jt] - t[ut]
-    #             temp.append(tdiff * (((vel[jt] - vel[ut]) / tdiff) ** 2.5))
-    #
-    #         m = np.nanmax(temp)
-    #         hic15.append(m)
-    #         time2.append(t[ut])
-    #
-    #     hic15.append(hic15[-1])
-    #     return np.array(hic15).reshape(-1, 1)
-
     @staticmethod
     def HIC(time: np.ndarray, a_res: np.ndarray, units, nidx):
         """
