@@ -395,7 +395,7 @@ class BinoutData(object):
         array_definition = json_object[JsonConstants.ARRAY]
         if array_definition[0].split(',')[0].strip(' (') == "all":
             converted_tuples = [(index, array_definition[0].split(',')[1].strip(' )')) for index, id_ in
-                                enumerate("ids")]
+                                enumerate(ids)]
         else:
             # processing data array
             converted_tuples = [(int(tuple_string.split(',')[0].strip(' (')), tuple_string.split(',')[1].strip(' )'))
