@@ -152,7 +152,7 @@ class MadymoData:
 
         i.e.
         ids = [1,2,3,4,5,6]
-        rx_acceleration only present for node 1,2,3
+        rx_acceleration only present for node 2/1, 2/2, 2/3
         rx_velocity only present for node 4,5,6
 
         read("nodout", "rx_acceleration") :
@@ -163,7 +163,7 @@ class MadymoData:
 
 
 
-        read("nodout", "rx_acceleration") :
+        read("nodout", "rx_velocity") :
         [[None, None, None, Value, Value, Value],
              ...
          [None, None, None, Value, Value, Value],
